@@ -248,12 +248,11 @@ disk_display_refresh (t_disk_display * disk_display)
     char * size;
     char * avail;
 
-    mount_info = disk_display->disk->mount_info;
-
     TRACE("enters disk_display_refresh");
 
     if (disk_display != NULL)
     {
+        mount_info = disk_display->disk->mount_info;
         if (mount_info != NULL)
         {    /* device is mounted */
             used = get_size_human_readable (mount_info->used);
@@ -367,14 +366,16 @@ mounter_data_new (t_mounter *mt)
     {
         disk = g_ptr_array_index (mt->pdisks, i); /* get the disk */
         disk_display = disk_display_new (disk, mt); /* creates a disk_display */
-        disk_display->disk = disk;
+        if (disk_display != NULL)
+            disk_display->disk = disk;
         g_ptr_array_add(disk_displays, disk_display);
         /* fill in mount infos */
         disk_display_refresh (disk_display);
 
         /* add the menu_item to the menu */
-        gtk_menu_shell_append (GTK_MENU_SHELL(mt->menu),
-                               disk_display->menu_item);
+        if (disk_display != NULL)
+            gtk_menu_shell_append (GTK_MENU_SHELL(mt->menu),
+                                   disk_display->menu_item);
     }
 
     gtk_widget_show_all(mt->menu);
@@ -761,11 +762,11 @@ mounter_create_options (XfcePanelPlugin *plugin, t_mounter *mt)
 
     xfce_panel_plugin_block_menu (plugin);
 
-    dlg = xfce_titled_dialog_new_with_buttons(
+    dlg = xfce_titled_dialog_new_with_mixed_buttons(
                 _("Mount Plugin"),
                 GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
                 GTK_DIALOG_DESTROY_WITH_PARENT,
-                "gtk-close", GTK_RESPONSE_OK, NULL);
+                "window-close-symbolic", _("_Close"), GTK_RESPONSE_OK, NULL);
 
     xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Properties"));
     gtk_window_set_icon_name(GTK_WINDOW(dlg),"drive-harddisk");
@@ -1089,7 +1090,7 @@ mounter_show_about(XfcePanelPlugin *plugin, t_mounter *mt)
       "program-name", PACKAGE_NAME,
       "comments", _("Show partitions/devices and allow to mount/unmount them"),
       "website", "https://docs.xfce.org/panel-plugins/xfce4-mount-plugin",
-      "copyright", "Copyright \302\251 2005-2023 The Xfce development team",
+      "copyright", "Copyright \302\251 2005-2024 The Xfce development team",
       "authors", auth, NULL);
   // TODO: add translators.
 }
